@@ -40,6 +40,12 @@ class BaseModel(models.Model):
     created_by_group = models.CharField(
         max_length=150, blank=True, null=True, db_index=True
     )
+    modified_by_user = models.CharField(
+        max_length=150, blank=True, null=True, db_index=True
+    )
+    modified_by_group = models.CharField(
+        max_length=150, blank=True, null=True, db_index=True
+    )
 
     def __str__(self):
         return str(self.pk)
